@@ -6,15 +6,15 @@
  * Author: Federico Mena-Quintero <federico@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -95,6 +95,8 @@ convert_status (const GNOME_Evolution_Calendar_CallStatus status)
 		return E_CALENDAR_STATUS_UNKNOWN_USER;
 	case GNOME_Evolution_Calendar_InvalidServerVersion:
 		return E_CALENDAR_STATUS_INVALID_SERVER_VERSION;
+	case GNOME_Evolution_Calendar_NoSuchCal:
+	      return E_CALENDAR_STATUS_NO_SUCH_CALENDAR;
 	
 	case GNOME_Evolution_Calendar_OtherError:
 	default:
