@@ -9,15 +9,15 @@
  *          Rodrigo Moya <rodrigo@ximian.com>    
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -105,6 +105,8 @@ e_cal_backend_get_type (void)
                         (GInstanceInitFunc) e_cal_backend_init,
                 };
 		e_cal_backend_type = g_type_register_static (G_TYPE_OBJECT, "ECalBackend", &info, 0);
+		if (!e_cal_backend_type)
+			g_warning ("Returned bad type\n");
 	}
 
 	return e_cal_backend_type;
@@ -297,7 +299,9 @@ e_cal_backend_finalize (GObject *object)
 
 	g_mutex_free (priv->clients_mutex);
 	g_mutex_free (priv->queries_mutex);
-
+	
+	g_free (priv->uri);
+	g_object_unref (priv->source);
 	g_free (priv);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -997,6 +1001,29 @@ e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzi
 }
 
 /**
+ * e_cal_backend_set_default_zone:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @tzobj: The timezone object, in a string.
+ * 
+ * Sets the default timezone for the calendar, which is used to resolve
+ * DATE and floating DATE-TIME values. 
+ */
+void
+e_cal_backend_set_default_zone (ECalBackend *backend, EDataCal *cal, const char *tzobj)
+{
+	g_return_if_fail (backend != NULL);
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
+	g_return_if_fail (tzobj != NULL);
+
+	(* CLASS (backend)->set_default_zone) (backend, cal, tzobj);
+}
+
+/**
+ * @deprecated This virual function should not be used in the backends, use
+ * e_cal_backend_set_zone instead. This function restricts the default timezone
+ * to be libical builtin timezone.
+ *
  * e_cal_backend_set_default_timezone:
  * @backend: A calendar backend.
  * @cal: An #EDataCal object.
@@ -1004,6 +1031,7 @@ e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzi
  * 
  * Sets the default timezone for the calendar, which is used to resolve
  * DATE and floating DATE-TIME values. 
+ * 
  */
 void
 e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
@@ -1012,7 +1040,6 @@ e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const c
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (tzid != NULL);
 
-	g_assert (CLASS (backend)->set_default_timezone != NULL);
 	(* CLASS (backend)->set_default_timezone) (backend, cal, tzid);
 }
 
@@ -1130,21 +1157,27 @@ e_cal_backend_notify_object_created (ECalBackend *backend, const char *calobj)
 static void
 match_query_and_notify (EDataCalView *query, const char *old_object, const char *object)
 {
-	gboolean old_match, new_match;
+	gboolean old_match = FALSE, new_match = FALSE;
+
+	if (old_object)
+		old_match = e_data_cal_view_object_matches (query, old_object);
 
-	old_match = e_data_cal_view_object_matches (query, old_object);
 	new_match = e_data_cal_view_object_matches (query, object);
 	if (old_match && new_match)
 		e_data_cal_view_notify_objects_modified_1 (query, object);
 	else if (new_match)
 		e_data_cal_view_notify_objects_added_1 (query, object);
 	else if (old_match) {
-		icalcomponent *icalcomp;
+		ECalComponent *comp = NULL;
 	
-		icalcomp = icalcomponent_new_from_string ((char *) old_object);
-		if (icalcomp) {
-			e_data_cal_view_notify_objects_removed_1 (query, icalcomponent_get_uid (icalcomp));
-			icalcomponent_free (icalcomp);
+		comp = e_cal_component_new_from_string (old_object);
+		if (comp) {
+			ECalComponentId *id = e_cal_component_get_id (comp);
+
+			e_data_cal_view_notify_objects_removed_1 (query, id);
+			
+			e_cal_component_free_id (id);
+			g_object_unref (comp);
 		}
 	}
 }
@@ -1274,7 +1307,7 @@ e_cal_backend_notify_object_modified (ECalBackend *backend,
 /**
  * e_cal_backend_notify_object_removed:
  * @backend: A calendar backend.
- * @uid: the UID of the removed object
+ * @id: the Id of the removed object
  * @old_object: iCalendar representation of the removed object
  * @new_object: iCalendar representation of the object after the removal. This
  * only applies to recurrent appointments that had an instance removed. In that
@@ -1287,7 +1320,7 @@ e_cal_backend_notify_object_modified (ECalBackend *backend,
  * removed by non-EDS clients.
  **/
 void
-e_cal_backend_notify_object_removed (ECalBackend *backend, const char *uid,
+e_cal_backend_notify_object_removed (ECalBackend *backend, const ECalComponentId *id,
 				     const char *old_object, const char *object)
 {
 	ECalBackendPrivate *priv;
@@ -1298,7 +1331,7 @@ e_cal_backend_notify_object_removed (ECalBackend *backend, const char *uid,
 	priv = backend->priv;
 
 	if (priv->notification_proxy) {
-		e_cal_backend_notify_object_removed (priv->notification_proxy, uid, old_object, object);
+		e_cal_backend_notify_object_removed (priv->notification_proxy, id, old_object, object);
 		return;
 	}
 
@@ -1314,7 +1347,7 @@ e_cal_backend_notify_object_removed (ECalBackend *backend, const char *uid,
 			/* if object == NULL, it means the object has been completely
 			   removed from the backend */
 			if (e_data_cal_view_object_matches (query, old_object))
-				e_data_cal_view_notify_objects_removed_1 (query, uid);
+				e_data_cal_view_notify_objects_removed_1 (query, id);
 		} else
 			match_query_and_notify (query, old_object, object);
 
