@@ -273,7 +273,7 @@ e_data_cal_view_set_property (GObject *object, guint property_id, const GValue *
 	
 	switch (property_id) {
 	case PROP_BACKEND:
-		priv->backend = E_CAL_BACKEND (g_value_dup_object (value));
+		priv->backend = E_CAL_BACKEND (g_value_get_object (value));
 		break;
 	case PROP_LISTENER:
 		e_data_cal_view_add_listener (query, g_value_get_pointer (value));
@@ -419,7 +419,15 @@ e_data_cal_view_new (ECalBackend *backend,
 		     ECalBackendSExp *sexp)
 {
 	EDataCalView *query;
+	if (!E_IS_CAL_BACKEND_SEXP (sexp)){
+		g_message ("Bad sexp passed\n");
+		return NULL;
+	}	
 
+	if (!E_IS_CAL_BACKEND (backend), NULL) {
+		g_message ("Bad backend passed\n");
+		return NULL;
+	}	
 	query = g_object_new (E_DATA_CAL_VIEW_TYPE, "backend", backend, "listener", ql,
 			      "sexp", sexp, NULL);
 
