@@ -3,8 +3,8 @@
   FILE: icalrecur.c
   CREATOR: eric 16 May 2000
   
-  $Id: icalrecur.c,v 1.15 2006/02/13 12:17:44 rsushma Exp $
-  $Locker:  $
+  $Id: icalrecur.c 547 2006-02-13 12:17:44Z rsushma $
+  $Locker$
     
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
