@@ -5,16 +5,16 @@
  *  Copyright 2001 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
@@ -53,6 +53,7 @@ static struct {
 } patterns[] = {
 	{ CONVERT_WEB_URLS, { "file://",   "",        camel_url_file_start,     camel_url_file_end     } },
 	{ CONVERT_WEB_URLS, { "ftp://",    "",        camel_url_web_start,      camel_url_web_end      } },
+	{ CONVERT_WEB_URLS, { "sftp://",   "",        camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "http://",   "",        camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "https://",  "",        camel_url_web_start,      camel_url_web_end      } },
 	{ CONVERT_WEB_URLS, { "news://",   "",        camel_url_web_start,      camel_url_web_end      } },
@@ -164,13 +165,13 @@ writeln (CamelMimeFilter *filter, const char *in, const char *inend, char *outpt
 {
 	CamelMimeFilterToHTML *html = (CamelMimeFilterToHTML *) filter;
 	const char *inptr = in;
-
+	
 	while (inptr < inend) {
 		guint32 u;
-
+		
 		outptr = check_size (filter, outptr, outend, 16);
-
-		u = camel_utf8_getc_limit ((const unsigned char **) &inptr, inend);
+		
+		u = camel_utf8_getc_limit ((const unsigned char **) &inptr, (const unsigned char *) inend);
 		switch (u) {
 		case 0xffff:
 			g_warning("Truncated utf8 buffer");
@@ -203,7 +204,7 @@ writeln (CamelMimeFilter *filter, const char *in, const char *inend, char *outpt
 			/* otherwise, FALL THROUGH */
 		case ' ':
 			if (html->flags & CAMEL_MIME_FILTER_TOHTML_CONVERT_SPACES
-			    && ((inptr == (in + 1) || *inptr == ' ' || *inptr == '\t'))) {
+			    && ((inptr == (in + 1) || (inptr < inend && (*inptr == ' ' || *inptr == '\t'))))) {
 				outptr = g_stpcpy (outptr, "&nbsp;");
 				html->column++;
 				break;
